@@ -450,20 +450,25 @@ func (p *Pager) initStyle() {
 
 	stringBuilder := strings.Builder{}
 	err := (*p.ChromaFormatter).Format(&stringBuilder, p.ChromaStyle, chroma.Literator(chroma.Token{
-		Type:  chroma.Other,
+		// FIXME: They Type here should really be None. "Background" is a
+		// workaround until we can bump Chroma to a release with this change in
+		// it:
+		// https://github.com/alecthomas/chroma/pull/869
+		Type: chroma.Background,
+
 		Value: "XXX",
 	}))
 	if err != nil {
 		panic(err)
 	}
 
-	string := stringBuilder.String()
-	cutoff := strings.Index(string, "XXX")
+	formatted := stringBuilder.String()
+	cutoff := strings.Index(formatted, "XXX")
 	if cutoff < 0 {
-		panic("XXX not found in " + string)
+		panic("XXX not found in " + formatted)
 	}
 
-	p.linePrefix = string[:cutoff]
+	p.linePrefix = formatted[:cutoff]
 }
 
 // StartPaging brings up the pager on screen
